Module config

Module config 

Ruda config module.

Modules

autotune
Autotune config module.
cache
Cache config module.
compilation
Compilation config module.
memory
Memory config module.
profiling
Profiling config module.
streaming
Streaming config module.

Structs

Logger
Central logging utility for Ruda, managing multiple log outputs.
RudaRuntimeConfig
Represents the global configuration for Ruda, combining profiling, autotuning, and compilation settings.

Enums

TypeNameFormatLevel
How to format ruda type names.

Traits

RuntimeConfig
Trait for runtime configurations potentially loaded from a TOML file.

Functions

type_name_format
Format a type name with different options.