pub enum RudaCountSelection {
Exact(RudaCount),
Approx(RudaCount, u32),
}Expand description
Defines how to select ruda count based on the number of rudas required.
Variants
Exact(RudaCount)
If the number of rudas is the same as required.
Approx(RudaCount, u32)
If the number of rudas isn’t the same as required.
This can happen based on the hardware limit, requiring the kernel to perform OOB checks.
Implementations