pub fn validate_ruda_dim(
properties: &DeviceProperties,
kernel_id: &KernelId,
) -> Result<(), LaunchError>Expand description
Validate the ruda dim of a kernel fits within the hardware limits
pub fn validate_ruda_dim(
properties: &DeviceProperties,
kernel_id: &KernelId,
) -> Result<(), LaunchError>Validate the ruda dim of a kernel fits within the hardware limits