pub enum MemoryAllocationMode {
Auto,
Persistent,
}Expand description
The mode of allocation used.
Variants
Auto
Use the automatic memory management strategy for allocation.
Persistent
Use a persistent memory management strategy, meaning that all allocations are for data that is likely never going to be freed.