pub struct StreamErrorMode {
pub ignore: bool,
pub flush: bool,
}Expand description
How errors are handled in a stream when executing a task.
Fields
ignore: boolWhether the task still executes even if the stream is in error.
flush: boolWhether the errors are flushed by the current task.